Title: [116559] trunk/Tools
Revision
116559
Author
[email protected]
Date
2012-05-09 14:56:11 -0700 (Wed, 09 May 2012)

Log Message

Remove CYGWIN=tty from environment variable as its no longer supported
https://bugs.webkit.org/show_bug.cgi?id=85791

The CYGWIN=tty environment variable is no longer supported from Cygwin
version 1.7.10. This fix avoids addition of this environment variable
for Cygwin versions greater than 1.7.9. For supporting older versions
i.e. 1.7.9 or older, the script takes care of retaining the environment
variable.

Patch by Vivek Galatage <[email protected]> on 2012-05-09
Reviewed by Adam Roben.

* Scripts/webkitdirs.pm:
(setupAppleWinEnv):

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (116558 => 116559)


--- trunk/Tools/ChangeLog	2012-05-09 21:27:36 UTC (rev 116558)
+++ trunk/Tools/ChangeLog	2012-05-09 21:56:11 UTC (rev 116559)
@@ -1,3 +1,19 @@
+2012-05-09  Vivek Galatage  <[email protected]>
+
+        Remove CYGWIN=tty from environment variable as its no longer supported
+        https://bugs.webkit.org/show_bug.cgi?id=85791
+
+        The CYGWIN=tty environment variable is no longer supported from Cygwin
+        version 1.7.10. This fix avoids addition of this environment variable
+        for Cygwin versions greater than 1.7.9. For supporting older versions
+        i.e. 1.7.9 or older, the script takes care of retaining the environment
+        variable.
+
+        Reviewed by Adam Roben.
+
+        * Scripts/webkitdirs.pm:
+        (setupAppleWinEnv):
+
 2012-05-09  Dirk Pranke  <[email protected]>
 
         nrwt: --skip-failing-tests should also skip flaky tests

Modified: trunk/Tools/Scripts/webkitdirs.pm (116558 => 116559)


--- trunk/Tools/Scripts/webkitdirs.pm	2012-05-09 21:27:36 UTC (rev 116558)
+++ trunk/Tools/Scripts/webkitdirs.pm	2012-05-09 21:56:11 UTC (rev 116559)
@@ -29,6 +29,7 @@
 # Module to share code to get to WebKit directories.
 
 use strict;
+use version;
 use warnings;
 use Config;
 use Digest::MD5 qw(md5_hex);
@@ -1487,9 +1488,15 @@
         my $restartNeeded = 0;
         my %variablesToSet = ();
 
-        # Setting the environment variable 'CYGWIN' to 'tty' makes cygwin enable extra support (i.e., termios)
-        # for UNIX-like ttys in the Windows console
-        $variablesToSet{CYGWIN} = "tty" unless $ENV{CYGWIN};
+        # FIXME: We should remove this explicit version check for cygwin once we stop supporting Cygwin 1.7.9 or older versions. 
+        # https://bugs.webkit.org/show_bug.cgi?id=85791
+        my $currentCygwinVersion = version->parse(`uname -r`);
+        my $firstCygwinVersionWithoutTTYSupport = version->parse("1.7.10");
+        if ($currentCygwinVersion < $firstCygwinVersionWithoutTTYSupport) {
+            # Setting the environment variable 'CYGWIN' to 'tty' makes cygwin enable extra support (i.e., termios)
+            # for UNIX-like ttys in the Windows console
+            $variablesToSet{CYGWIN} = "tty" unless $ENV{CYGWIN};
+        }
         
         # Those environment variables must be set to be able to build inside Visual Studio.
         $variablesToSet{WEBKITLIBRARIESDIR} = windowsLibrariesDir() unless $ENV{WEBKITLIBRARIESDIR};
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to